@@ -3,10 +3,10 @@
 use strict;
 use warnings;
 
-use Error::Pure::ANSIColor::ErrorList qw(err);
+use Error::Pure::ANSIColor::Print qw(err);
 
 # Error.
 err '1', '2', '3';
 
 # Output:
-# #Error [example2.pl:9] 1
\ No newline at end of file
+# 1
\ No newline at end of file
